@@ -2,24 +2,13 @@
 set -e
 
 ARTIFACT_DIR=${ARTIFACT_DIR:-_output}
-manifest=$(mktemp)
-global_manifest=$(mktemp)
-
-# save generated manifest files in _output directory for debugging purposes
-cleanup(){
-  local return_code="$?"
-  set +e
-
-  cp ${manifest} $ARTIFACT_DIR/manifest
-  cp ${global_manifest} $ARTIFACT_DIR/global_manifest
-  rm -rf ${manifest}
-  rm -rf ${global_manifest}
-  exit $return_code
-}
-
-trap cleanup exit
+manifest=${ARTIFACT_DIR}/manifest.yaml
+global_manifest=${ARTIFACT_DIR}/global_manifest.yaml
+rm -f $manifest $global_manifest
+mkdir -p ${ARTIFACT_DIR}
 
 if [ -n "${IMAGE_FORMAT}" ] ; then
+    echo "IMAGE_FORMAT set as '${IMAGE_FORMAT}'"
     IMAGE_LOCAL_STORAGE_OPERATOR=$(sed -e "s,\${component},local-storage-operator," <(echo $IMAGE_FORMAT))
     IMAGE_LOCAL_DISKMAKER=$(sed -e "s,\${component},local-storage-diskmaker," <(echo $IMAGE_FORMAT))
 else
@@ -32,14 +21,21 @@ repo_dir="$(dirname $0)/.."
 cat ${repo_dir}/deploy/sa.yaml >> ${manifest}
 cat ${repo_dir}/deploy/rbac.yaml >> ${manifest}
 cat ${repo_dir}/deploy/operator.yaml >> ${manifest}
-cat ${repo_dir}/deploy/crd.yaml >> ${global_manifest}
+cat ${repo_dir}/deploy/localvolume_crd.yaml >> ${global_manifest}
+cat ${repo_dir}/deploy/localvolumeset_crd.yaml >> ${global_manifest}
+cat ${repo_dir}/deploy/localvolumediscovery_crd.yaml >> ${global_manifest}
+cat ${repo_dir}/deploy/localvolumediscoveryresult_crd.yaml >> ${global_manifest}
 
 sed -i "s,quay.io/openshift/origin-local-storage-operator,${IMAGE_LOCAL_STORAGE_OPERATOR}," ${manifest}
 sed -i "s,quay.io/openshift/origin-local-storage-diskmaker,${IMAGE_LOCAL_DISKMAKER}," ${manifest}
-export TEST_NAMESPACE=${TEST_NAMESPACE:-default}
-export TEST_LOCAL_DISK=${TEST_LOCAL_DISK:-""}
+NAMESPACE=${NAMESPACE:-default}
+LOCAL_DISK=${LOCAL_DISK:-""}
 
-go test ./test/e2e/... \
+export \
+    IMAGE_LOCAL_STORAGE_OPERATOR \
+    IMAGE_LOCAL_DISKMAKER
+
+TEST_NAMESPACE=${NAMESPACE} TEST_LOCAL_DISK=${LOCAL_DISK} go test -timeout 0 ./test/e2e/... \
   -root=$(pwd) \
   -kubeconfig=${KUBECONFIG} \
   -globalMan ${global_manifest} \
